After you obtained results from permkCCA_multipleRegion() function,
there are two ways to summarize and save information of
kcca objects at group level (i.e. construct region-level conenctivity network):
(1) for each patient i, you can spcify patientID = i and saveFormat="excel",
and then store the output in csv files. The generated csv files have 7 columns:
row number, index1, index2, region1, region2, pvalue, indicator of significance,
and count flag (always 1). See example 1 for more information.
(2) if you do not want save information in csv files, you can specify
saveFormat="group" abd then this function can help you summarize group
level information for all patients. The output variables have 7 columns: row number, index1,
index2, region1, region2, pvalue, indicator of significance, and count flag (always 1).
If you want to save data as other format such as latex, you can directly copy
the generated latex code to your tex file. See example 3 for more information.
Note that if returned object has length 0 (i.e. no connection), then warning message will be generated.